@@ -33,10 +33,7 @@
 
 G_BEGIN_DECLS
 
-#define GEXIV2_METADATA_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), GEXIV2_TYPE_METADATA, GExiv2MetadataPrivate))
-
-G_DEFINE_TYPE (GExiv2Metadata, gexiv2_metadata, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_CODE (GExiv2Metadata, gexiv2_metadata, G_TYPE_OBJECT, G_ADD_PRIVATE (GExiv2Metadata));
 
 static void gexiv2_metadata_finalize (GObject *object);
 static void gexiv2_metadata_set_comment_internal (GExiv2Metadata *self, const gchar *new_comment);
@@ -46,7 +43,7 @@ static gboolean gexiv2_metadata_save_internal (GExiv2Metadata *self, Exiv2::Imag
 
 static void gexiv2_metadata_init (GExiv2Metadata *self) {
     GExiv2MetadataPrivate *priv;
-    self->priv = priv = GEXIV2_METADATA_GET_PRIVATE (self);
+    self->priv = priv = (GExiv2MetadataPrivate *) gexiv2_metadata_get_instance_private(self);
     
     /* Initialize members */
     self->priv->comment = NULL;
@@ -71,8 +68,6 @@ static void gexiv2_metadata_init (GExiv2Metadata *self) {
 static void gexiv2_metadata_class_init (GExiv2MetadataClass *klass) {
     GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
     
-    g_type_class_add_private (klass, sizeof (GExiv2MetadataPrivate));
-    
     gobject_class->finalize = gexiv2_metadata_finalize;
 }
 
@@ -539,8 +534,8 @@ gint gexiv2_metadata_get_metadata_pixel_height (GExiv2Metadata *self) {
         if (gexiv2_metadata_has_exif_tag(self, "Exif.Photo.PixelYDimension"))
             return gexiv2_metadata_get_exif_tag_long(self, "Exif.Photo.PixelYDimension");
         
-        if (gexiv2_metadata_has_exif_tag(self, "Exif.Image.ImageHeight"))
-            return gexiv2_metadata_get_exif_tag_long(self, "Exif.Image.ImageHeight");
+        if (gexiv2_metadata_has_exif_tag(self, "Exif.Image.ImageLength"))
+            return gexiv2_metadata_get_exif_tag_long(self, "Exif.Image.ImageLength");
     }
     
     if (gexiv2_metadata_has_xmp(self)) {
@@ -564,7 +559,7 @@ void gexiv2_metadata_set_metadata_pixel_width (GExiv2Metadata *self, gint width)
     exif_data["Exif.Photo.PixelXDimension"] = static_cast<uint32_t>(width);
     exif_data["Exif.Image.ImageWidth"] = static_cast<uint32_t>(width);
     xmp_data["Xmp.tiff.ImageWidth"] = static_cast<uint32_t>(width);
-    xmp_data["Xmp.exif.PixelYDimension"] = static_cast<uint32_t>(width);
+    xmp_data["Xmp.exif.PixelXDimension"] = static_cast<uint32_t>(width);
 }
 
 void gexiv2_metadata_set_metadata_pixel_height (GExiv2Metadata *self, gint height) {
@@ -574,10 +569,10 @@ void gexiv2_metadata_set_metadata_pixel_height (GExiv2Metadata *self, gint heigh
     Exiv2::ExifData& exif_data = self->priv->image->exifData();
     Exiv2::XmpData& xmp_data = self->priv->image->xmpData();
     
-    exif_data ["Exif.Photo.PixelXDimension"] = static_cast<uint32_t>(height);
-    exif_data ["Exif.Image.ImageHeight"] = static_cast<uint32_t>(height);
-    xmp_data ["Xmp.tiff.ImageHeight"] = static_cast<uint32_t>(height);
-    xmp_data ["Xmp.exif.PixelXDimension"] = static_cast<uint32_t>(height);
+    exif_data ["Exif.Photo.PixelYDimension"] = static_cast<uint32_t>(height);
+    exif_data ["Exif.Image.ImageLength"] = static_cast<uint32_t>(height);
+    xmp_data ["Xmp.tiff.ImageLength"] = static_cast<uint32_t>(height);
+    xmp_data ["Xmp.exif.PixelYDimension"] = static_cast<uint32_t>(height);
 }
 
 gchar* gexiv2_metadata_get_comment (GExiv2Metadata *self) {
